@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-reverse-datetree" "0.4.4"
+(define-package "org-reverse-datetree" "20250513.848"
   "Create reverse date trees in org-mode."
   '((emacs "29.1")
     (dash  "2.19.1")
